@@ -26,6 +26,7 @@ use {
         path::PathBuf,
         process::Command,
     },
+    which::which,
 };
 
 /// description of a possible launch of an external program
@@ -71,6 +72,16 @@ fn resolve_env_variables(parts: Vec<String>) -> Vec<String> {
                 resolved.extend(val.split(' ').map(|s| s.to_string()));
                 continue;
             }
+            if var_name == "EDITOR" {
+                debug!("Env var $EDITOR not set, looking at editor command for fallback");
+                if let Ok(editor) = which("editor") {
+                    if let Some(editor) = editor.to_str() {
+                        debug!("Using editor solved as {editor:?}");
+                        resolved.push(editor.to_string());
+                        continue;
+                    }
+                }
+            }
         }
         resolved.push(part);
     }
